# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentSummary(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'net_amount': 'float',
        'net_amount_local': 'float',
        'gross_amount_local': 'float',
        'vat_amount': 'float',
        'vat_amount_local': 'float',
        'vat_rate_summary': 'list[DocumentVatRateSummary]'
    }

    attribute_map = {
        'net_amount': 'net_amount',
        'net_amount_local': 'net_amount_local',
        'gross_amount_local': 'gross_amount_local',
        'vat_amount': 'vat_amount',
        'vat_amount_local': 'vat_amount_local',
        'vat_rate_summary': 'vat_rate_summary'
    }

    def __init__(self, net_amount=None, net_amount_local=None, gross_amount_local=None, vat_amount=None, vat_amount_local=None, vat_rate_summary=None):  # noqa: E501
        """DocumentSummary - a model defined in Swagger"""  # noqa: E501
        self._net_amount = None
        self._net_amount_local = None
        self._gross_amount_local = None
        self._vat_amount = None
        self._vat_amount_local = None
        self._vat_rate_summary = None
        self.discriminator = None
        if net_amount is not None:
            self.net_amount = net_amount
        if net_amount_local is not None:
            self.net_amount_local = net_amount_local
        if gross_amount_local is not None:
            self.gross_amount_local = gross_amount_local
        if vat_amount is not None:
            self.vat_amount = vat_amount
        if vat_amount_local is not None:
            self.vat_amount_local = vat_amount_local
        if vat_rate_summary is not None:
            self.vat_rate_summary = vat_rate_summary

    @property
    def net_amount(self):
        """Gets the net_amount of this DocumentSummary.  # noqa: E501


        :return: The net_amount of this DocumentSummary.  # noqa: E501
        :rtype: float
        """
        return self._net_amount

    @net_amount.setter
    def net_amount(self, net_amount):
        """Sets the net_amount of this DocumentSummary.


        :param net_amount: The net_amount of this DocumentSummary.  # noqa: E501
        :type: float
        """

        self._net_amount = net_amount

    @property
    def net_amount_local(self):
        """Gets the net_amount_local of this DocumentSummary.  # noqa: E501


        :return: The net_amount_local of this DocumentSummary.  # noqa: E501
        :rtype: float
        """
        return self._net_amount_local

    @net_amount_local.setter
    def net_amount_local(self, net_amount_local):
        """Sets the net_amount_local of this DocumentSummary.


        :param net_amount_local: The net_amount_local of this DocumentSummary.  # noqa: E501
        :type: float
        """

        self._net_amount_local = net_amount_local

    @property
    def gross_amount_local(self):
        """Gets the gross_amount_local of this DocumentSummary.  # noqa: E501


        :return: The gross_amount_local of this DocumentSummary.  # noqa: E501
        :rtype: float
        """
        return self._gross_amount_local

    @gross_amount_local.setter
    def gross_amount_local(self, gross_amount_local):
        """Sets the gross_amount_local of this DocumentSummary.


        :param gross_amount_local: The gross_amount_local of this DocumentSummary.  # noqa: E501
        :type: float
        """

        self._gross_amount_local = gross_amount_local

    @property
    def vat_amount(self):
        """Gets the vat_amount of this DocumentSummary.  # noqa: E501


        :return: The vat_amount of this DocumentSummary.  # noqa: E501
        :rtype: float
        """
        return self._vat_amount

    @vat_amount.setter
    def vat_amount(self, vat_amount):
        """Sets the vat_amount of this DocumentSummary.


        :param vat_amount: The vat_amount of this DocumentSummary.  # noqa: E501
        :type: float
        """

        self._vat_amount = vat_amount

    @property
    def vat_amount_local(self):
        """Gets the vat_amount_local of this DocumentSummary.  # noqa: E501


        :return: The vat_amount_local of this DocumentSummary.  # noqa: E501
        :rtype: float
        """
        return self._vat_amount_local

    @vat_amount_local.setter
    def vat_amount_local(self, vat_amount_local):
        """Sets the vat_amount_local of this DocumentSummary.


        :param vat_amount_local: The vat_amount_local of this DocumentSummary.  # noqa: E501
        :type: float
        """

        self._vat_amount_local = vat_amount_local

    @property
    def vat_rate_summary(self):
        """Gets the vat_rate_summary of this DocumentSummary.  # noqa: E501


        :return: The vat_rate_summary of this DocumentSummary.  # noqa: E501
        :rtype: list[DocumentVatRateSummary]
        """
        return self._vat_rate_summary

    @vat_rate_summary.setter
    def vat_rate_summary(self, vat_rate_summary):
        """Sets the vat_rate_summary of this DocumentSummary.


        :param vat_rate_summary: The vat_rate_summary of this DocumentSummary.  # noqa: E501
        :type: list[DocumentVatRateSummary]
        """

        self._vat_rate_summary = vat_rate_summary

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentSummary, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentSummary):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateDocumentExport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'query_type': 'DocumentExportQueryType',
        'start_date': 'date',
        'end_date': 'date',
        'document_block_id': 'int',
        'export_type': 'DocumentExportType',
        'number_start_year': 'int',
        'number_start_sequence': 'int',
        'number_end_year': 'int',
        'number_end_sequence': 'int',
        'payment_method': 'PaymentMethod',
        'sort_by': 'DocumentExportSortBy',
        'other_options': 'DocumentExportOtherOptions',
        'filter_extra': 'DocumentExportFilterExtra'
    }

    attribute_map = {
        'query_type': 'query_type',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'document_block_id': 'document_block_id',
        'export_type': 'export_type',
        'number_start_year': 'number_start_year',
        'number_start_sequence': 'number_start_sequence',
        'number_end_year': 'number_end_year',
        'number_end_sequence': 'number_end_sequence',
        'payment_method': 'payment_method',
        'sort_by': 'sort_by',
        'other_options': 'other_options',
        'filter_extra': 'filter_extra'
    }

    def __init__(self, query_type=None, start_date=None, end_date=None, document_block_id=None, export_type=None, number_start_year=None, number_start_sequence=None, number_end_year=None, number_end_sequence=None, payment_method=None, sort_by=None, other_options=None, filter_extra=None):  # noqa: E501
        """CreateDocumentExport - a model defined in Swagger"""  # noqa: E501
        self._query_type = None
        self._start_date = None
        self._end_date = None
        self._document_block_id = None
        self._export_type = None
        self._number_start_year = None
        self._number_start_sequence = None
        self._number_end_year = None
        self._number_end_sequence = None
        self._payment_method = None
        self._sort_by = None
        self._other_options = None
        self._filter_extra = None
        self.discriminator = None
        self.query_type = query_type
        self.start_date = start_date
        self.end_date = end_date
        if document_block_id is not None:
            self.document_block_id = document_block_id
        self.export_type = export_type
        if number_start_year is not None:
            self.number_start_year = number_start_year
        if number_start_sequence is not None:
            self.number_start_sequence = number_start_sequence
        if number_end_year is not None:
            self.number_end_year = number_end_year
        if number_end_sequence is not None:
            self.number_end_sequence = number_end_sequence
        if payment_method is not None:
            self.payment_method = payment_method
        if sort_by is not None:
            self.sort_by = sort_by
        if other_options is not None:
            self.other_options = other_options
        if filter_extra is not None:
            self.filter_extra = filter_extra

    @property
    def query_type(self):
        """Gets the query_type of this CreateDocumentExport.  # noqa: E501


        :return: The query_type of this CreateDocumentExport.  # noqa: E501
        :rtype: DocumentExportQueryType
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """Sets the query_type of this CreateDocumentExport.


        :param query_type: The query_type of this CreateDocumentExport.  # noqa: E501
        :type: DocumentExportQueryType
        """
        if query_type is None:
            raise ValueError("Invalid value for `query_type`, must not be `None`")  # noqa: E501

        self._query_type = query_type

    @property
    def start_date(self):
        """Gets the start_date of this CreateDocumentExport.  # noqa: E501


        :return: The start_date of this CreateDocumentExport.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CreateDocumentExport.


        :param start_date: The start_date of this CreateDocumentExport.  # noqa: E501
        :type: date
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this CreateDocumentExport.  # noqa: E501


        :return: The end_date of this CreateDocumentExport.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CreateDocumentExport.


        :param end_date: The end_date of this CreateDocumentExport.  # noqa: E501
        :type: date
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def document_block_id(self):
        """Gets the document_block_id of this CreateDocumentExport.  # noqa: E501


        :return: The document_block_id of this CreateDocumentExport.  # noqa: E501
        :rtype: int
        """
        return self._document_block_id

    @document_block_id.setter
    def document_block_id(self, document_block_id):
        """Sets the document_block_id of this CreateDocumentExport.


        :param document_block_id: The document_block_id of this CreateDocumentExport.  # noqa: E501
        :type: int
        """

        self._document_block_id = document_block_id

    @property
    def export_type(self):
        """Gets the export_type of this CreateDocumentExport.  # noqa: E501


        :return: The export_type of this CreateDocumentExport.  # noqa: E501
        :rtype: DocumentExportType
        """
        return self._export_type

    @export_type.setter
    def export_type(self, export_type):
        """Sets the export_type of this CreateDocumentExport.


        :param export_type: The export_type of this CreateDocumentExport.  # noqa: E501
        :type: DocumentExportType
        """
        if export_type is None:
            raise ValueError("Invalid value for `export_type`, must not be `None`")  # noqa: E501

        self._export_type = export_type

    @property
    def number_start_year(self):
        """Gets the number_start_year of this CreateDocumentExport.  # noqa: E501


        :return: The number_start_year of this CreateDocumentExport.  # noqa: E501
        :rtype: int
        """
        return self._number_start_year

    @number_start_year.setter
    def number_start_year(self, number_start_year):
        """Sets the number_start_year of this CreateDocumentExport.


        :param number_start_year: The number_start_year of this CreateDocumentExport.  # noqa: E501
        :type: int
        """

        self._number_start_year = number_start_year

    @property
    def number_start_sequence(self):
        """Gets the number_start_sequence of this CreateDocumentExport.  # noqa: E501


        :return: The number_start_sequence of this CreateDocumentExport.  # noqa: E501
        :rtype: int
        """
        return self._number_start_sequence

    @number_start_sequence.setter
    def number_start_sequence(self, number_start_sequence):
        """Sets the number_start_sequence of this CreateDocumentExport.


        :param number_start_sequence: The number_start_sequence of this CreateDocumentExport.  # noqa: E501
        :type: int
        """

        self._number_start_sequence = number_start_sequence

    @property
    def number_end_year(self):
        """Gets the number_end_year of this CreateDocumentExport.  # noqa: E501


        :return: The number_end_year of this CreateDocumentExport.  # noqa: E501
        :rtype: int
        """
        return self._number_end_year

    @number_end_year.setter
    def number_end_year(self, number_end_year):
        """Sets the number_end_year of this CreateDocumentExport.


        :param number_end_year: The number_end_year of this CreateDocumentExport.  # noqa: E501
        :type: int
        """

        self._number_end_year = number_end_year

    @property
    def number_end_sequence(self):
        """Gets the number_end_sequence of this CreateDocumentExport.  # noqa: E501


        :return: The number_end_sequence of this CreateDocumentExport.  # noqa: E501
        :rtype: int
        """
        return self._number_end_sequence

    @number_end_sequence.setter
    def number_end_sequence(self, number_end_sequence):
        """Sets the number_end_sequence of this CreateDocumentExport.


        :param number_end_sequence: The number_end_sequence of this CreateDocumentExport.  # noqa: E501
        :type: int
        """

        self._number_end_sequence = number_end_sequence

    @property
    def payment_method(self):
        """Gets the payment_method of this CreateDocumentExport.  # noqa: E501


        :return: The payment_method of this CreateDocumentExport.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this CreateDocumentExport.


        :param payment_method: The payment_method of this CreateDocumentExport.  # noqa: E501
        :type: PaymentMethod
        """

        self._payment_method = payment_method

    @property
    def sort_by(self):
        """Gets the sort_by of this CreateDocumentExport.  # noqa: E501


        :return: The sort_by of this CreateDocumentExport.  # noqa: E501
        :rtype: DocumentExportSortBy
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """Sets the sort_by of this CreateDocumentExport.


        :param sort_by: The sort_by of this CreateDocumentExport.  # noqa: E501
        :type: DocumentExportSortBy
        """

        self._sort_by = sort_by

    @property
    def other_options(self):
        """Gets the other_options of this CreateDocumentExport.  # noqa: E501


        :return: The other_options of this CreateDocumentExport.  # noqa: E501
        :rtype: DocumentExportOtherOptions
        """
        return self._other_options

    @other_options.setter
    def other_options(self, other_options):
        """Sets the other_options of this CreateDocumentExport.


        :param other_options: The other_options of this CreateDocumentExport.  # noqa: E501
        :type: DocumentExportOtherOptions
        """

        self._other_options = other_options

    @property
    def filter_extra(self):
        """Gets the filter_extra of this CreateDocumentExport.  # noqa: E501


        :return: The filter_extra of this CreateDocumentExport.  # noqa: E501
        :rtype: DocumentExportFilterExtra
        """
        return self._filter_extra

    @filter_extra.setter
    def filter_extra(self, filter_extra):
        """Sets the filter_extra of this CreateDocumentExport.


        :param filter_extra: The filter_extra of this CreateDocumentExport.  # noqa: E501
        :type: DocumentExportFilterExtra
        """

        self._filter_extra = filter_extra

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDocumentExport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDocumentExport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OnlineSzamlaStatusEnum(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    ABORTED = "aborted"
    DONE = "done"
    EMPTY_ORGANIZATION_COUNTRY_CODE = "empty_organization_country_code"
    EMPTY_PARTNER_COUNTRY_CODE = "empty_partner_country_code"
    EMPTY_TAX = "empty_tax"
    FORBIDDEN = "forbidden"
    INVALID_ADDRESS = "invalid_address"
    INVALID_CLIENT = "invalid_client"
    INVALID_CONVERSION_RATE = "invalid_conversion_rate"
    INVALID_CUSTOMER = "invalid_customer"
    INVALID_INVOICE_REFERENCE = "invalid_invoice_reference"
    INVALID_POSTALCODE = "invalid_postalcode"
    INVALID_SECURITY_USER = "invalid_security_user"
    INVALID_TAX = "invalid_tax"
    INVALID_TAX_NUMBER = "invalid_tax_number"
    INVALID_USER_RELATION = "invalid_user_relation"
    INVALID_VAT_DATA = "invalid_vat_data"
    INVOICE_NUMBER_NOT_UNIQUE = "invoice_number_not_unique"
    KOBAK_PROCESSING = "kobak_processing"
    MISSING_DOCUMENT_ITEM_NAME = "missing_document_item_name"
    NAV_WARN = "nav_warn"
    NO_ONLINE_SZAMLA_SETTINGS = "no_online_szamla_settings"
    NO_SEND_BY_USER = "no_send_by_user"
    NON_EXIST_TAX_NUMBER = "non_exist_tax_number"
    NOT_UNIQUE = "not unique"
    NOT_CHECKED = "not_checked"
    NOT_REGISTERED_CUSTOMER = "not_registered_customer"
    PROCESSING = "processing"
    RECEIVED = "received"
    SAVED = "saved"
    SEND_FAILED = "send_failed"
    SENT = "sent"
    STARTED = "started"
    TECHNICAL_ERROR = "technical_error"
    UNDER_TAX_LIMIT = "under_tax_limit"
    USER_HAS_INVALID_KOBAK = "user_has_invalid_kobak"
    USER_HASNOT_KOBAK = "user_hasnot_kobak"
    VALIDATION_OK = "validation_ok"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """OnlineSzamlaStatusEnum - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OnlineSzamlaStatusEnum, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnlineSzamlaStatusEnum):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Product(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'comment': 'str',
        'currency': 'Currency',
        'vat': 'Vat',
        'net_unit_price': 'float',
        'unit': 'str',
        'general_ledger_number': 'str',
        'general_ledger_taxcode': 'str',
        'entitlement': 'Entitlement'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'comment': 'comment',
        'currency': 'currency',
        'vat': 'vat',
        'net_unit_price': 'net_unit_price',
        'unit': 'unit',
        'general_ledger_number': 'general_ledger_number',
        'general_ledger_taxcode': 'general_ledger_taxcode',
        'entitlement': 'entitlement'
    }

    def __init__(self, id=None, name=None, comment=None, currency=None, vat=None, net_unit_price=None, unit=None, general_ledger_number=None, general_ledger_taxcode=None, entitlement=None):  # noqa: E501
        """Product - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._comment = None
        self._currency = None
        self._vat = None
        self._net_unit_price = None
        self._unit = None
        self._general_ledger_number = None
        self._general_ledger_taxcode = None
        self._entitlement = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.name = name
        if comment is not None:
            self.comment = comment
        self.currency = currency
        self.vat = vat
        if net_unit_price is not None:
            self.net_unit_price = net_unit_price
        self.unit = unit
        if general_ledger_number is not None:
            self.general_ledger_number = general_ledger_number
        if general_ledger_taxcode is not None:
            self.general_ledger_taxcode = general_ledger_taxcode
        if entitlement is not None:
            self.entitlement = entitlement

    @property
    def id(self):
        """Gets the id of this Product.  # noqa: E501


        :return: The id of this Product.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Product.


        :param id: The id of this Product.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Product.  # noqa: E501


        :return: The name of this Product.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Product.


        :param name: The name of this Product.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def comment(self):
        """Gets the comment of this Product.  # noqa: E501


        :return: The comment of this Product.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Product.


        :param comment: The comment of this Product.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def currency(self):
        """Gets the currency of this Product.  # noqa: E501


        :return: The currency of this Product.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Product.


        :param currency: The currency of this Product.  # noqa: E501
        :type: Currency
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def vat(self):
        """Gets the vat of this Product.  # noqa: E501


        :return: The vat of this Product.  # noqa: E501
        :rtype: Vat
        """
        return self._vat

    @vat.setter
    def vat(self, vat):
        """Sets the vat of this Product.


        :param vat: The vat of this Product.  # noqa: E501
        :type: Vat
        """
        if vat is None:
            raise ValueError("Invalid value for `vat`, must not be `None`")  # noqa: E501

        self._vat = vat

    @property
    def net_unit_price(self):
        """Gets the net_unit_price of this Product.  # noqa: E501


        :return: The net_unit_price of this Product.  # noqa: E501
        :rtype: float
        """
        return self._net_unit_price

    @net_unit_price.setter
    def net_unit_price(self, net_unit_price):
        """Sets the net_unit_price of this Product.


        :param net_unit_price: The net_unit_price of this Product.  # noqa: E501
        :type: float
        """

        self._net_unit_price = net_unit_price

    @property
    def unit(self):
        """Gets the unit of this Product.  # noqa: E501


        :return: The unit of this Product.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this Product.


        :param unit: The unit of this Product.  # noqa: E501
        :type: str
        """
        if unit is None:
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501

        self._unit = unit

    @property
    def general_ledger_number(self):
        """Gets the general_ledger_number of this Product.  # noqa: E501


        :return: The general_ledger_number of this Product.  # noqa: E501
        :rtype: str
        """
        return self._general_ledger_number

    @general_ledger_number.setter
    def general_ledger_number(self, general_ledger_number):
        """Sets the general_ledger_number of this Product.


        :param general_ledger_number: The general_ledger_number of this Product.  # noqa: E501
        :type: str
        """

        self._general_ledger_number = general_ledger_number

    @property
    def general_ledger_taxcode(self):
        """Gets the general_ledger_taxcode of this Product.  # noqa: E501


        :return: The general_ledger_taxcode of this Product.  # noqa: E501
        :rtype: str
        """
        return self._general_ledger_taxcode

    @general_ledger_taxcode.setter
    def general_ledger_taxcode(self, general_ledger_taxcode):
        """Sets the general_ledger_taxcode of this Product.


        :param general_ledger_taxcode: The general_ledger_taxcode of this Product.  # noqa: E501
        :type: str
        """

        self._general_ledger_taxcode = general_ledger_taxcode

    @property
    def entitlement(self):
        """Gets the entitlement of this Product.  # noqa: E501


        :return: The entitlement of this Product.  # noqa: E501
        :rtype: Entitlement
        """
        return self._entitlement

    @entitlement.setter
    def entitlement(self, entitlement):
        """Sets the entitlement of this Product.


        :param entitlement: The entitlement of this Product.  # noqa: E501
        :type: Entitlement
        """

        self._entitlement = entitlement

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Product, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Product):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.models.document_export_query_type import DocumentExportQueryType  # noqa: E501
from billingo.rest import ApiException


class TestDocumentExportQueryType(unittest.TestCase):
    """DocumentExportQueryType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocumentExportQueryType(self):
        """Test DocumentExportQueryType"""
        # FIXME: construct object with mandatory attributes with example values
        # model = billingo.models.document_export_query_type.DocumentExportQueryType()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
